<?php

/**
 * This is the model class for table "category".
 *
 * The followings are the available columns in table 'category':
 * @property string $id
 * @property string $name
 * @property string $parent_id
 *
 * The followings are the available model relations:
 * @property Category $parent
 * @property Category[] $categories
 * @property Product[] $products
 */
class Category extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Category the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'category';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('name', 'required'),
			array('name', 'length', 'max'=>128),
			array('parent_id', 'length', 'max'=>10),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, name, parent_id', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'parent' => array(self::BELONGS_TO, 'Category', 'parent_id'),
			'categories' => array(self::HAS_MANY, 'Category', 'parent_id'),
			'products' => array(self::MANY_MANY, 'Product', 'category_product(category_id, product_id)'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'name' => 'Name',
			'parent_id' => 'Parent',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id,true);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('parent_id',$this->parent_id,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
    
    protected $_categoryTree=array();
    protected $_categoryFlat=array();  
    
    public function getCategoryTree($format)
    {
        $categories=self::model()->findAll(array('order'=>'position'));
        foreach($categories as $category){
            if($category->parent_id==null) $category->parent_id=0;
            $this->_categoryTree[$category->parent_id][$category->id]=$category->name;        
        }
        
        switch($format){
        case 'flat':
            $this->level2Label();   
            return $this->_categoryFlat;               
            break;
        case 'tree':
            return $this->formatTree();                   
            break;
        }
    }
    
    protected function level2Label($parent_id=0,$level=0)
    {                                          
        foreach($this->_categoryTree[$parent_id] as $key=>$val){
            $this->_categoryFlat[$key]=str_repeat('&nbsp;',4*$level).$val;
            if(isset($this->_categoryTree[$key]) && $key>0)
                $this->level2Label($key,$level+1);
        }
    }
    
    protected function formatTree($parent_id=0)
    {
        $data=array();
        foreach($this->_categoryTree[$parent_id] as $key=>$val){            
            $children=isset($this->_categoryTree[$key])?$this->formatTree($key):null; 
            $expand=$children?true:false;                           
            $data[]=array('id'=>$key,'title'=>$val,'icon'=>false,'expand'=>$expand,'children'=>$children);            
        }   
        return $data;
    }
}